=========
Citations
=========

GUNC: Detection of Chimerism and Contamination in Prokaryotic Genomes
---------------------------------------------------------------------

Askarbek Orakov, Anthony Fullam, Luis Pedro Coelho, Supriya Khedkar, Damian Szklarczyk, Daniel R. Mende, Thomas SB Schmidt, Peer Bork

`Genome Biol <https://genomebiology.biomedcentral.com/articles/10.1186/s13059-021-02393-0>`_ 22, 178 (2021) doi: https://doi.org/10.1186/s13059-021-02393-0

`bioRxiv <https://www.biorxiv.org/content/10.1101/2020.12.16.422776v1>`_ 2020.12.16.422776; doi: https://doi.org/10.1101/2020.12.16.422776

------------

Software used by GUNC
---------------------

Prodigal
^^^^^^^^

Prodigal: prokaryotic gene recognition and translation initiation site identification
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

Hyatt, D., Chen, GL., LoCascio, P.F. et al.

BMC Bioinformatics 11, 119 (2010). https://doi.org/10.1186/1471-2105-11-119

`Prodigal GitHub <https://github.com/hyattpd/Prodigal>`_


Diamond
^^^^^^^

Sensitive protein alignments at tree-of-life scale using DIAMOND
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

Buchfink B, Reuter K, Drost HG

Nature Methods 18, 366-368 (2021). doi:10.1038/s41592-021-01101-x

`Diamond GitHub <https://github.com/bbuchfink/diamond>`_
